
/* 
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:  
 *       "This product includes software developed by the 
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Jakarta-Regexp", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */ 

// Java stuff
import java.util.*;
import java.io.StringWriter;
import java.io.PrintWriter;
import java.io.IOException;
import java.io.FileNotFoundException;
import java.io.FileInputStream;

// Servlet stuff
import javax.servlet.*;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

// WebStringTemplates
import au.com.forward.webstringtemplate.*;

// Demo stuff
import action.*;

/**
 * Main entry point into the forum application.
 * All requests are made to this servlet.
 * 
 * @author <a href="mailto:daveb@miceda-data.com">Dave Bryson</a>
 * @version $Revision: 1.2 $
 * $Id: ControllerServlet.java,v 1.2 2004-01-26 19:43:43+11 matthew_ford Exp matthew_ford $
 *
 * Modified by Matthew Ford to use WebStringTemplates
 */
 
public class ControllerServlet extends HttpServlet {

	// just one group for all threads
	static WebStringTemplateGroup forumGroup = null; 
	
	public void init() throws ServletException {
		forumGroup = WebStringTemplateServer.getInstanceOfGroup(getServletContext(), "forumGroup",
				getServletContext().getRealPath("/") + "st");
	}
	
	public void doGet(HttpServletRequest req,
			HttpServletResponse resp)
			 throws ServletException, IOException {

		// create a WebStringTemplate to use instead of a Velocity context
		WebStringTemplate context = new WebStringTemplate(forumGroup);
				
     Command c = null;
     WebStringTemplate template = null;
     String name = req.getParameter("action");
        
        if ( name == null || name.length() == 0 ) {
            throw new RuntimeException("Unrecognized action request!");
        }
                
        if ( name.equalsIgnoreCase("list") )
        {
					try {
            c = new ListCommand( req, resp);
            template = c.exec( context );
					} catch (Throwable t){
						throw new RuntimeException("Error getting list",t);
					}
        }
        else if ( name.equalsIgnoreCase("post") ) 
        {
            c = new PostCommand( req, resp );
            template = c.exec( context ); 
        }
        else if (  name.equalsIgnoreCase("reply") )
        {
            c = new ReplyCommand( req, resp );
            template = c.exec( context );
        }
        else if (  name.equalsIgnoreCase("postreply") )
        {
            c = new PostReplyCommand( req, resp );
            template = c.exec( context );
        }
        else if ( name.equalsIgnoreCase("view") )
        {
            c = new ViewCommand( req, resp );
            template = c.exec( context );
        } else if ( name == null || name.length() == 0 ) {
            throw new RuntimeException("Unrecognized action request '"+name+"'");
        }
				
				// ok now output the result
				PrintWriter out = resp.getWriter();
				// then write the data to the response
				template.write(out);
				
				// to write out the attributes on the end of the output page uncomment the next two lines.
				//template.setAttribute(WebStringTemplate.OUTPUT_DATA_DEFINITION_FLAG,"true");
				//template.write(out);
				
				out.close();

	}

			
	public void doPost(HttpServletRequest req, HttpServletResponse resp)
			 throws ServletException, java.io.IOException {
		doGet(req, resp);
	}

	public String getServletInfo() {
		return "A WebStringTemplate version of Apache's Velocity forumdemo.";
	}
				

}





